@@ -22,13 +22,14 @@ class Neo4jHelper:
     Neo4j   数据库操作实现
     """
 
-    def __init__(self, pool):
+    def __init__(self, pool, access=neo4j.READ_ACCESS):
         """
         初始化sql工具
         :param pool: 连接池名称
         """
         if isinstance(pool, str):
             self.pool, self.dialect = options.database[pool]
+            self.pool = self.pool.session(database=pool, default_access_mode=access)
         else:
             self.pool = pool
 
@@ -55,6 +56,7 @@ class Neo4jHelper:
             for key in keys:
                 rows.append(record[key])
             data.append(rows)
+        await self.pool.close()
         return data
 
     async def dictreader(self, cypher):
@@ -76,6 +78,7 @@ class Neo4jHelper:
                 exec
                 "item.update(dict({0}))".format(args)
             data.append(item)
+        await self.pool.close()
         return data
 
     async def dictreaderopted(self, cypher, keys=None):
@@ -100,6 +103,7 @@ class Neo4jHelper:
                 for key in keys:
                     item.update({key: record[key]})
                 data.append(item)
+            await self.pool.close()
             return data
 
     async def cypherexecuter(self, cypher):
@@ -110,7 +114,9 @@ class Neo4jHelper:
         :return: none.
         """
         async with self.pool.begin_transaction() as tx:
-            return await tx.run(cypher)
+            res = await tx.run(cypher)
+        await self.pool.close()
+        return res
 
     async def parse_relation_data(self, cql, result_list, id_key="id", name_key="name"):
         data = []
@@ -341,6 +347,7 @@ class Neo4jHelper:
             else:
                 raise Exception("node1 and node2 are not exist")
         results = await self.pool.read_transaction(self.query_work, sql)
+        await self.pool.close()
         records = []
         for record in results:
             records.append(parse_record(record, flag=True))
@@ -380,6 +387,7 @@ class Neo4jHelper:
         records = []
         for record in results:
             records.append(parse_record(record, flag=False))
+        await self.pool.close()
         return records
 
     async def query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
@@ -448,6 +456,7 @@ class Neo4jHelper:
         records = []
         for record in results:
             records.append(parse_record(record, flag=False))
+        await self.pool.close()
         return Page(records=records, current=page_num, page_size=page_size, total=total).__dict__
 
     async def execute_fetchall(self, sql, flag=True):
@@ -467,7 +476,9 @@ class Neo4jHelper:
 
     async def execute_write(self, sql):
         summary = await self.pool.write_transaction(self.sync_write_work, sql)
-        return eval(summary.counters.__repr__())
+        res = eval(summary.counters.__repr__())
+        await self.pool.close()
+        return res
 
     def sync_listreader(self, cypher, keys):
         """
@@ -480,15 +491,17 @@ class Neo4jHelper:
         :return: list
             Each returned record constructs a list and stored in a big list, [[...], [...], ...].
         """
+        data = []
         with self.pool.begin_transaction() as tx:
-            data = []
+
             result = tx.run(cypher)
             for record in result:
                 rows = []
                 for key in keys:
                     rows.append(record[key])
                 data.append(rows)
-            return data
+        self.pool.close()
+        return data
 
     def sync_dictreader(self, cypher):
         """
@@ -500,15 +513,15 @@ class Neo4jHelper:
         :return: list
             Each returned record constructs a dict in "key : value" pairs and stored in a big list, [{...}, {...}, ...].
         """
+        data = []
         with self.pool.begin_transaction() as tx:
-            data = []
             for record in tx.run(cypher).records():
                 item = {}
                 for args in str(record).split('>')[0].split()[1:]:
                     exec
                     "item.update(dict({0}))".format(args)
                 data.append(item)
-            return data
+        return data
 
     def sync_dictreaderopted(self, cypher, keys=None):
         """
@@ -524,15 +537,15 @@ class Neo4jHelper:
         if not keys:
             return self.sync_dictreader(cypher)
         else:
+            data = []
             with self.pool.begin_transaction() as tx:
-                data = []
                 result = tx.run(cypher)
                 for record in result:
                     item = {}
                     for key in keys:
                         item.update({key: record[key]})
                     data.append(item)
-                return data
+            return data
 
     def sync_cypherexecuter(self, cypher):
         """
@@ -882,6 +895,7 @@ class Neo4jHelper:
         records = []
         for record in results:
             records.append(parse_record(record, flag=False))
+        self.pool.close()
         return Page(records=records, current=page_num, page_size=page_size, total=total).__dict__
 
     def sync_query_work(self, tx, sql):
@@ -892,6 +906,7 @@ class Neo4jHelper:
         records = []
         for record in results:
             records.append(parse_record(record, flag=flag))
+        self.pool.close()
         return records
 
     def sync_write_work(self, tx, sql):
@@ -899,7 +914,9 @@ class Neo4jHelper:
 
     def sync_execute_write(self, sql):
         summary = self.pool.write_transaction(self.sync_write_work, sql)
-        return eval(summary.counters.__repr__())
+        res = eval(summary.counters.__repr__())
+        self.pool.close()
+        return res
 
 
 def parse_relation_item(item, id_key, name_key, level=0):
