@@ -69,6 +69,8 @@ class StatusCode:
     INVALID_TIME_STAMP = ("A0321", "非法的时间戳参数")
     USER_INPUT_INVALID = ("A0322", "用户输入内容非法")
     UNSUPPORTED_SERVICE_TYPE_ERROR = ("A0323", "不支持的服务类型")
+    FEISHU_UNBOUND = ("A0324", "飞书未绑定")
+    FEISHU_BOUNDED = ("A0325", "飞书已绑定")
 
     @staticmethod
     def REQUIRED_PARAM_IS_EMPTY(message):
